/*
 * Copyright © 2012 Red Hat Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Alexander Larsson <alexl@gnome.org>
 */

#pragma once

#include <gtk/css/gtkcss.h>
#include "gtk/css/gtkcsstokenizerprivate.h"
#include "gtk/css/gtkcssparserprivate.h"
#include "gtkcssvalueprivate.h"

G_BEGIN_DECLS

GtkCssValue *   gtk_css_palette_value_new_default       (void);

GtkCssValue *   gtk_css_palette_value_parse             (GtkCssParser        *parser);

GtkCssValue *   gtk_css_palette_value_get_color         (GtkCssValue         *value,
                                                         const char          *color_name);

GtkCssValue *   gtk_css_palette_value_resolve           (GtkCssValue          *value,
                                                         GtkCssComputeContext *context,
                                                         GtkCssValue          *current_color);

G_END_DECLS

